pub struct SpaceWeatherData {
pub records: BTreeMap<Epoch, RawSpaceWeatherRow>,
pub fallback: StaticSpaceWeather,
}Expand description
Stores SpaceWeather data as provided by CelesTrak. Data may be provided either as original CSV or in a compressed (non-archived) gunzip (gz) format.
Fields
records: BTreeMap<Epoch, RawSpaceWeatherRow>fallback: StaticSpaceWeatherImplementations
Sourceimpl SpaceWeatherData
impl SpaceWeatherData
Sourcepub fn from_static_weather(weather: StaticSpaceWeather) -> Self
pub fn from_static_weather(weather: StaticSpaceWeather) -> Self
Initialize new space weather by provided fixed values only.
Sourcepub fn from_csv_file<P: AsRef<Path>>(
path: P,
fallback: StaticSpaceWeather,
) -> Result<Self, InputOutputError>
pub fn from_csv_file<P: AsRef<Path>>( path: P, fallback: StaticSpaceWeather, ) -> Result<Self, InputOutputError>
Ingests a complete CelesTrak Space Weather CSV file into an Epoch-indexed map.
Sourcepub fn raw_daily_record(
&self,
midnight_epoch: Epoch,
) -> Option<&RawSpaceWeatherRow>
pub fn raw_daily_record( &self, midnight_epoch: Epoch, ) -> Option<&RawSpaceWeatherRow>
Returns a reference to the raw, unparsed daily row for an exact midnight UTC epoch.
Sourceimpl SpaceWeatherData
impl SpaceWeatherData
Sourcepub fn msise_weather(&self, epoch: Epoch) -> Msise00DailyWeather
pub fn msise_weather(&self, epoch: Epoch) -> Msise00DailyWeather
Evaluates the space weather state at epoch and constructs the Msise00DailyWeather payload.
Missing daily records or unforecasted fields are resolved using SpaceWeatherFallback.